==> jc-1.4.0.tar.gz: java/rmi/activation/ActivationGroupID.h <==
// public class java.rmi.activation.ActivationGroupID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cbaf666effd62b1a java_rmi_activation_ActivationGroupID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_activation_ActivationGroupID_H_
#define _JC_java_rmi_activation_ActivationGroupID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_activation_ActivationSystem$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationGroupID$sub_refs	_jc_java_rmi_activation_ActivationGroupID$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$sub_nonrefs	_jc_java_rmi_activation_ActivationGroupID$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$refs	_jc_java_rmi_activation_ActivationGroupID$refs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$nonrefs	_jc_java_rmi_activation_ActivationGroupID$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$object	_jc_java_rmi_activation_ActivationGroupID$object;

typedef struct _jc_java_rmi_activation_ActivationGroupID$fields_struct	_jc_java_rmi_activation_ActivationGroupID$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationGroupID$vmethods	_jc_java_rmi_activation_ActivationGroupID$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationGroupID$vtable	_jc_java_rmi_activation_ActivationGroupID$vtable;
typedef const struct _jc_java_rmi_activation_ActivationGroupID$vtype	_jc_java_rmi_activation_ActivationGroupID$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationGroupID$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationGroupID$fields_struct _jc_java_rmi_activation_ActivationGroupID$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationGroupID$method$_init$95d10d48f1e254fd(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_java_rmi_activation_ActivationGroupID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_rmi_activation_ActivationGroupID$method$getSystem$31603400e2ddfccb(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *);
extern jint _jc_java_rmi_activation_ActivationGroupID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationGroupID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_activation_ActivationGroupID$method_info$getSystem$31603400e2ddfccb;
extern _jc_method _jc_java_rmi_activation_ActivationGroupID$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationGroupID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getSystem$31603400e2ddfccb)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *);
};

// Vtable
struct _jc_java_rmi_activation_ActivationGroupID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_activation_ActivationGroupID$vmethods	java_rmi_activation_ActivationGroupID;
};

// Vtype
struct _jc_java_rmi_activation_ActivationGroupID$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationGroupID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupID$sub_refs {
	struct _jc_object	*system;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupID$refs {
    _jc_java_rmi_activation_ActivationGroupID$sub_refs	java_rmi_activation_ActivationGroupID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_activation_ActivationGroupID$sub_nonrefs	java_rmi_activation_ActivationGroupID;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationGroupID$object {
	_jc_java_rmi_activation_ActivationGroupID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationGroupID$vtype	*vtype;
	_jc_java_rmi_activation_ActivationGroupID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationGroupID$vtype _jc_java_rmi_activation_ActivationGroupID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationGroupID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationGroupID$class_object;

#endif	/* _JC_java_rmi_activation_ActivationGroupID_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/ActivationGroupID.h <==
// public class java.rmi.activation.ActivationGroupID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cbaf666effd62b1a java_rmi_activation_ActivationGroupID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_activation_ActivationGroupID_H_
#define _JC_java_rmi_activation_ActivationGroupID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_activation_ActivationSystem$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationGroupID$sub_refs	_jc_java_rmi_activation_ActivationGroupID$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$sub_nonrefs	_jc_java_rmi_activation_ActivationGroupID$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$refs	_jc_java_rmi_activation_ActivationGroupID$refs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$nonrefs	_jc_java_rmi_activation_ActivationGroupID$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupID$object	_jc_java_rmi_activation_ActivationGroupID$object;

typedef struct _jc_java_rmi_activation_ActivationGroupID$fields_struct	_jc_java_rmi_activation_ActivationGroupID$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationGroupID$vmethods	_jc_java_rmi_activation_ActivationGroupID$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationGroupID$vtable	_jc_java_rmi_activation_ActivationGroupID$vtable;
typedef const struct _jc_java_rmi_activation_ActivationGroupID$vtype	_jc_java_rmi_activation_ActivationGroupID$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationGroupID$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationGroupID$fields_struct _jc_java_rmi_activation_ActivationGroupID$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationGroupID$method$_init$95d10d48f1e254fd(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_activation_ActivationGroupID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_activation_ActivationGroupID$method$getSystem$31603400e2ddfccb(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_activation_ActivationGroupID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationGroupID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_activation_ActivationGroupID$method_info$getSystem$31603400e2ddfccb;
extern _jc_method _jc_java_rmi_activation_ActivationGroupID$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationGroupID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSystem$31603400e2ddfccb)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_activation_ActivationGroupID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_activation_ActivationGroupID$vmethods	java_rmi_activation_ActivationGroupID;
};

// Vtype
struct _jc_java_rmi_activation_ActivationGroupID$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationGroupID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupID$sub_refs {
	struct _jc_object	*system;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupID$refs {
    _jc_java_rmi_activation_ActivationGroupID$sub_refs	java_rmi_activation_ActivationGroupID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_activation_ActivationGroupID$sub_nonrefs	java_rmi_activation_ActivationGroupID;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationGroupID$object {
	_jc_java_rmi_activation_ActivationGroupID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationGroupID$vtype	*vtype;
	_jc_java_rmi_activation_ActivationGroupID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationGroupID$vtype _jc_java_rmi_activation_ActivationGroupID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationGroupID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationGroupID$class_object;

#endif	/* _JC_java_rmi_activation_ActivationGroupID_H_ */
